package com.mysql.jdbc.jdbc2.optional;

import com.mysql.jdbc.ConnectionImpl;
import com.mysql.jdbc.Constants;
import com.mysql.jdbc.log.Log;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import javax.sql.XAConnection;
import javax.transaction.xa.XAException;
import javax.transaction.xa.XAResource;
import javax.transaction.xa.Xid;

/* loaded from: com_mysql_jdbc_jdbc2_optional.jar:com/mysql/jdbc/jdbc2/optional/MysqlXAConnection.class */
public class MysqlXAConnection extends MysqlPooledConnection implements XAConnection, XAResource {
    private ConnectionImpl underlyingConnection;
    private static final Map MYSQL_ERROR_CODES_TO_XA_ERROR_CODES;
    private Log log;
    protected boolean logXaCommands;

    static {
        HashMap temp = new HashMap();
        temp.put(Constants.integerValueOf(1397), Constants.integerValueOf(-4));
        temp.put(Constants.integerValueOf(1398), Constants.integerValueOf(-5));
        temp.put(Constants.integerValueOf(1399), Constants.integerValueOf(-7));
        temp.put(Constants.integerValueOf(1400), Constants.integerValueOf(-9));
        temp.put(Constants.integerValueOf(1401), Constants.integerValueOf(-3));
        temp.put(Constants.integerValueOf(1402), Constants.integerValueOf(100));
        MYSQL_ERROR_CODES_TO_XA_ERROR_CODES = Collections.unmodifiableMap(temp);
    }

    public MysqlXAConnection(ConnectionImpl connection, boolean logXaCommands) throws SQLException {
        super(connection);
        this.underlyingConnection = connection;
        this.log = connection.getLog();
        this.logXaCommands = logXaCommands;
    }

    public XAResource getXAResource() throws SQLException {
        return this;
    }

    public int getTransactionTimeout() throws XAException {
        return 0;
    }

    public boolean setTransactionTimeout(int arg0) throws XAException {
        return false;
    }

    public boolean isSameRM(XAResource xares) throws XAException {
        if (xares instanceof MysqlXAConnection) {
            return this.underlyingConnection.isSameResource(((MysqlXAConnection) xares).underlyingConnection);
        }
        return false;
    }

    public Xid[] recover(int flag) throws XAException {
        return recover(this.underlyingConnection, flag);
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:35:0x0121
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    protected static javax.transaction.xa.Xid[] recover(java.sql.Connection r7, int r8) throws javax.transaction.xa.XAException {
        /*
            Method dump skipped, instructions count: 356
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.jdbc2.optional.MysqlXAConnection.recover(java.sql.Connection, int):javax.transaction.xa.Xid[]");
    }

    public int prepare(Xid xid) throws XAException {
        StringBuffer commandBuf = new StringBuffer();
        commandBuf.append("XA PREPARE ");
        commandBuf.append(xidToString(xid));
        dispatchCommand(commandBuf.toString());
        return 0;
    }

    public void forget(Xid xid) throws XAException {
    }

    public void rollback(Xid xid) throws XAException {
        StringBuffer commandBuf = new StringBuffer();
        commandBuf.append("XA ROLLBACK ");
        commandBuf.append(xidToString(xid));
        try {
            dispatchCommand(commandBuf.toString());
            this.underlyingConnection.setInGlobalTx(false);
        } catch (Throwable th) {
            this.underlyingConnection.setInGlobalTx(false);
            throw th;
        }
    }

    public void end(Xid xid, int flags) throws XAException {
        StringBuffer commandBuf = new StringBuffer();
        commandBuf.append("XA END ");
        commandBuf.append(xidToString(xid));
        switch (flags) {
            case 33554432:
                commandBuf.append(" SUSPEND");
                break;
            case 67108864:
            case 536870912:
                break;
            default:
                throw new XAException(-5);
        }
        dispatchCommand(commandBuf.toString());
    }

    public void start(Xid xid, int flags) throws XAException {
        StringBuffer commandBuf = new StringBuffer();
        commandBuf.append("XA START ");
        commandBuf.append(xidToString(xid));
        switch (flags) {
            case 0:
                break;
            case 2097152:
                commandBuf.append(" JOIN");
                break;
            case 134217728:
                commandBuf.append(" RESUME");
                break;
            default:
                throw new XAException(-5);
        }
        dispatchCommand(commandBuf.toString());
        this.underlyingConnection.setInGlobalTx(true);
    }

    public void commit(Xid xid, boolean onePhase) throws XAException {
        StringBuffer commandBuf = new StringBuffer();
        commandBuf.append("XA COMMIT ");
        commandBuf.append(xidToString(xid));
        if (onePhase) {
            commandBuf.append(" ONE PHASE");
        }
        try {
            dispatchCommand(commandBuf.toString());
            this.underlyingConnection.setInGlobalTx(false);
        } catch (Throwable th) {
            this.underlyingConnection.setInGlobalTx(false);
            throw th;
        }
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:9:0x0062
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    private java.sql.ResultSet dispatchCommand(java.lang.String r5) throws javax.transaction.xa.XAException {
        /*
            r4 = this;
            r0 = 0
            r6 = r0
            r0 = r4
            boolean r0 = r0.logXaCommands     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            if (r0 == 0) goto L25
            r0 = r4
            com.mysql.jdbc.log.Log r0 = r0.log     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            java.lang.StringBuffer r1 = new java.lang.StringBuffer     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            r2 = r1
            r2.<init>()     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            java.lang.String r2 = "Executing XA statement: "
            java.lang.StringBuffer r1 = r1.append(r2)     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            r2 = r5
            java.lang.StringBuffer r1 = r1.append(r2)     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            java.lang.String r1 = r1.toString()     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            r0.logDebug(r1)     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
        L25:
            r0 = r4
            com.mysql.jdbc.ConnectionImpl r0 = r0.underlyingConnection     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            java.sql.Statement r0 = r0.createStatement()     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            r6 = r0
            r0 = r6
            r1 = r5
            boolean r0 = r0.execute(r1)     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            r0 = r6
            java.sql.ResultSet r0 = r0.getResultSet()     // Catch: java.sql.SQLException -> L45 java.lang.Throwable -> L4b
            r7 = r0
            r0 = r7
            r8 = r0
            r0 = jsr -> L53
        L42:
            r1 = r8
            return r1
        L45:
            r7 = move-exception
            r0 = r7
            javax.transaction.xa.XAException r0 = mapXAExceptionFromSQLException(r0)     // Catch: java.lang.Throwable -> L4b
            throw r0     // Catch: java.lang.Throwable -> L4b
        L4b:
            r9 = move-exception
            r0 = jsr -> L53
        L50:
            r1 = r9
            throw r1
        L53:
            r10 = r0
            r0 = r6
            if (r0 == 0) goto L64
            r0 = r6
            r0.close()     // Catch: java.sql.SQLException -> L62
            goto L64
        L62:
            r11 = move-exception
        L64:
            ret r10
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.jdbc2.optional.MysqlXAConnection.dispatchCommand(java.lang.String):java.sql.ResultSet");
    }

    protected static XAException mapXAExceptionFromSQLException(SQLException sqlEx) {
        Integer xaCode = (Integer) MYSQL_ERROR_CODES_TO_XA_ERROR_CODES.get(Constants.integerValueOf(sqlEx.getErrorCode()));
        if (xaCode != null) {
            return new MysqlXAException(xaCode.intValue(), sqlEx.getMessage(), null);
        }
        return new MysqlXAException(sqlEx.getMessage(), null);
    }

    private static String xidToString(Xid xid) {
        byte[] gtrid = xid.getGlobalTransactionId();
        byte[] btrid = xid.getBranchQualifier();
        int lengthAsString = 6;
        if (gtrid != null) {
            lengthAsString = 6 + (2 * gtrid.length);
        }
        if (btrid != null) {
            lengthAsString += 2 * btrid.length;
        }
        String formatIdInHex = Integer.toHexString(xid.getFormatId());
        StringBuffer asString = new StringBuffer(lengthAsString + formatIdInHex.length() + 3);
        asString.append("0x");
        if (gtrid != null) {
            for (byte b : gtrid) {
                String asHex = Integer.toHexString(b & 255);
                if (asHex.length() == 1) {
                    asString.append("0");
                }
                asString.append(asHex);
            }
        }
        asString.append(",");
        if (btrid != null) {
            asString.append("0x");
            for (byte b2 : btrid) {
                String asHex2 = Integer.toHexString(b2 & 255);
                if (asHex2.length() == 1) {
                    asString.append("0");
                }
                asString.append(asHex2);
            }
        }
        asString.append(",0x");
        asString.append(formatIdInHex);
        return asString.toString();
    }

    @Override // com.mysql.jdbc.jdbc2.optional.MysqlPooledConnection, javax.sql.PooledConnection
    public synchronized Connection getConnection() throws SQLException {
        Connection connToWrap = getConnection(false, true);
        return connToWrap;
    }
}
